# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

- v0.5 Added generic classes for arbitrary number of labels and classifiers.
       These are ntqr.raxioms.MAxiomsIdeal and
       ntqr.evaluations.MLabelResponseSimplexes

- v0.6 Added ntqr.evaluations classes to handle generic number of classifiers
       and labels. Varieties up to m=2 are now computable.


### Changed

### Removed

## [0.5.1] - 2025-04-25
## [0.6]   - 2025-05-09
## [0.6.1] - 2025-05-15
## [0.6.2] - 2025-05-19

### Added

### Fixed

- Incorrect processing of labels in ntqr.raxioms.MAxiomsIdeal._m_two_ideal.

- v0.6.1 Fixed bugs for the M=1,2 axioms expressed in terms of 'errors'
         variables. Updated the Jupyter notebook documentation accordingly.
- v0.6.2 Fixed bug in the M=2 axioms as implemented in
         ntqr.raxioms.MAxiomsIdeal.

### Changed

### Removed

## [0.7] - 2025-08-25

### Added

- new dataclass MVariety to contain the set of group evaluations given up
  to M=m statistics. Mostly important, it allows the __and__ operation of
  equal or lesser order.
- new dataclass MVarietyTupleDict to save space while carrying out exact
  computations.

### Fixed

### Changed

### Removed


